| Title: | C++ infrastructure for representing and interacting with the gated cytometry data |
|---|---|
| Description: | This package provides the core data structure and API to represent and interact with the gated cytometry data. |
| Authors: | Mike Jiang |
| Maintainer: | Mike Jiang <[email protected]> |
| License: | AGPL-3.0-only |
| Version: | 2.25.0 |
| Built: | 2026-05-28 06:31:44 UTC |
| Source: | https://github.com/bioc/cytolib |
PKG_LIBS += $(shell "$R_HOME/bin$R_ARCH_BIN/Rscript.exe" -e "cytolib::cytolib_LdFlags()")
cytolib_LdFlags()cytolib_LdFlags()